package com.zerog.ia.customcode.util.miscutils;

import java.io.*;
import java.net.*;
import java.awt.*;

public class ImageUtils
{
	/**
	 *	Loads an image from a URL, blocks until image is loaded.
	 *
	 *	@return Image if the image is found
	 *	@return null if the image is not found
	 */
	public static Image loadImageFromURL( URL sourceImage )
	{
		ImageComponent ic = new ImageComponent();
		return loadImageFromURL( sourceImage, ic );
	}

	/**
	 *	Loads an image from a URL, blocks until image is loaded.
	 *
	 *	@return Image if the image is found
	 *	@return null if the image is not found
	 */
	public static Image loadImageFromURL( URL sourceImage, Component c )
	{
		if ( sourceImage == null )
		{
			System.err.println(
				"ImageUtils.loadImageFromURL: sourceImage is null" );
			return null;
		}

		Image img = null;
		img = Toolkit.getDefaultToolkit().getImage( sourceImage );

		MediaTracker mt = new MediaTracker(c);

		try
		{
	        mt.addImage( img, 0 );
	        if ( ! mt.checkID( 0 ) ) // check if it's already loaded
			{
			    mt.waitForID( 0 );

				if ( mt.isErrorID( 0 ) )
				{
					System.err.println(
					"ImageUtils.loadImageFromURL: Error while loading image");
					return null;
				}
			}
		} catch( InterruptedException ie ) {
			// ok, just return what we've got so far
		} finally {
			mt.removeImage( img, 0 );
		}

		return img;
	}
}
